*** LATIN AMERICA RECODE AND EXPLORE DATA

cd "/Users/aneundorf/Dropbox/Legacy of authoritarian regimes data/"
*cd "/Users/ldzan/Dropbox/Legacy of authoritarian regimes data/"

set more off
clear all

*-----------------------------------------------------------------------------
**** LATINOBAROMETER
*-----------------------------------------------------------------------------

use "Latinobarometer/latinobarometro_all_merged.dta", clear

keep country year surveymode sampling fulldem howdem demsat solvesprob govtapprove govgood bestgovt ///
democracybest stronglead polinterest turnout conf_president conf_parl conf_judic conf_party conf_milit ///
conf_admin conf_gov conf_police conf_media conf_union subjsalary marstat sex birthyear age religion ///
relstrength end_edu education employment typework_last typework econsit  trust leri

**------------------------
* Full democracy
* NOTE: This question was only asked in 2013 and 2004

tab fulldem
recode fulldem (-2=.) (-1=5) // DK were recoded to "I do not understand what a democracy is"
tab fulldem, gen(fulldem) // Create dummy variables for eahc option


**------------------------
* How democracy
* NOTE: This question was only asked 9 times between 1997 and 2013
* Was also asked twice in WVS, but covers same time as LB

tab howdem
recode howdem (-4/-1=.)

gen howdem_dum = (howdem-1)/9
tab howdem_dum
lab var howdem_dum "0-1: Assess how democratic [country] is"
lab def howdem_lbl 0"completly undemcartic" 1"Completley democratic"
lab val howdem_dum howdem_lbl


**------------------------
* Democracic satisfaction
* NOTE: This question was only asked 17 times between 1995 and 2013
* Was also asked in WVS and AB several times, but covers same time as LB

tab demsat
recode demsat (-4/-1=.) (1=4) (2=3) (3=2) (4=1)

gen demsat_dum = (demsat-1)/3
lab var demsat_dum "0-1: Satisfaction with democarcy" 
label define sat_lab1 1 "very satisfied" 0 "not at all satisfied"
label values demsat_dum sat_lab1
tab demsat_dum


**------------------------
* Democracy solves problems
* NOTE: This question was only asked 4 times between 1995 and 2009

tab solvesprob
recode solvesprob (-4/-1=.) (2=0)


**------------------------
* Democracy attitudes combined
pwcorr fulldem1 fulldem5 howdem demsat solvesprob 



**------------------------
* Government approval
* NOTE: This question was only asked 4 times between 2002 and 2013

tab govtapprove
recode govtapprove (-4/-1=.) (2=0)


**------------------------
* Government good to all people
* NOTE: This question was only asked 4 times between 2004 and 2013
* Should be combined with WVS

tab govgood
recode govgood (-4/-1=.) (2=1) (1=0)



**------------------------
* Which best form of gov
* NOTE: This question was only asked 4 times between 1995 and 2013

tab bestgovt
recode bestgovt (-4/-1=.) 
tab bestgovt, gen( bestgovt)


**------------------------
* Democarcy best form of gov
* NOTE: This question was only asked 11 times between 2004 and 2013
* Should be combined with WVS

tab democracybest
recode democracybest (-4/-1=.) (1=4) (2=3) (3=2) (4=1)

gen democracybest_dum = (democracybest-1)/3
label variable democracybest_dum "0-1: Democracy may have problems but it is the best system of govt"
label define agree_lab2 1 "agree" 0 "disagree"
label values democracybest_dum agree_lab2
tab democracybest_dum


pwcorr democracybest bestgovt1 // correlation very weak


**------------------------
* Strong leader better than parliament
* NOTE: This question was only asked 2 times between 2003 and 2013
* Should be combined with WVS and AB

tab stronglead
recode stronglead (-4/-1=.) 


**------------------------
* Political interest
* NOTE: This question was only asked 2 times between 2003 and 2013
* Should be combined with WVS and AB

tab polinterest
recode polinterest (-4/-1=.) (1=4) (2=3) (3=2) (4=1)

gen polint_dum = (polinterest-1)/3
label variable polint_dum "0-1: Political interest"
label define int_lab2 1 "very" 0 "not at all"
label values polint_dum int_lab2
tab polint_dum


**------------------------
* Turnout

tab turnout
recode turnout (-4/-1=.) (2/8=0) 
tab turnout

**------------------------
* Confidence in institutions


tab conf_president
label define conf_lab2 1 "lot" 0 "no trust"

foreach i in  gov president parl judic party milit admin police media union {
recode conf_`i' (-4/-1=.) (1=4) (2=3) (3=2) (4=1)
gen conf_`i'_dum = (conf_`i'-1)/3
label variable conf_`i'_dum "0-1: Confidence in `i'"
label values conf_`i'_dum conf_lab2
tab conf_`i'_dum
}

**------------------------
* Interpersonal trust

tab trust
recode trust (-4/-1=.) (2=0) 

label define trust_lab1 1 " Most people can be trusted" 0 "one can never be too careful when dealing with others"
label values trust trust_lab1


**------------------------
* Left-right
tab leri
recode leri (-4/-1=.)

gen leri_dum = (leri)/10
tab leri_dum
lab var leri_dum "0-1: Left-Right self-placement"
lab def leri_lbl1 0"Left" 1"Right"
lab val leri_dum leri_lbl1
tab leri_dum

save "Analysis/Latinobarometer_ForMerge", replace


**------------------------
* IVs

**------------------------
* Cohorts

* 1. Birth year

sum birth,d
*kdensity birth
drop if birth<1920

*** 5-year cohorts: averaged macro data will be matched when R' were between 15 and 19 old
*drop cohort5
gen cohort5=.
set more off
foreach num of numlist 1920(5)1995 {
	replace cohort5 = `num' if birth==`num' | birth==`num'+1 | birth==`num'+2 | birth==`num'+3 | birth==`num'+4 
	}
lab var cohort5 "Cohorts devided into 5-year birth intervals"
recode cohort5 (1995=1990)
replace cohort5 = 1990 if birth==1996 | birth==1997
tab cohort5,m

tab birth if cohort5==.

*** 2-year cohorts
*drop cohort2
gen cohort2=.
set more off
foreach num of numlist 1920(2)1997 {
	replace cohort2 = `num' if birth==`num' | birth==`num'+1  
	} 
lab var cohort2 "Cohorts devided into 2-year birth intervals"
recode cohort2 (1920=1922) (1996=1994)
tab cohort2


* 2. Birth year + y

foreach y in 10 15 20 25  {
gen cohortmatch5_`y' = cohort5+`y'
lab var cohortmatch5_`y' "5-year cohorts year plus `y' years" 
}

foreach y in 10 12 14 16 18 20 {
gen cohortmatch2_`y' = cohort2 + `y'
lab var cohortmatch2_`y' "2-year cohorts year plus `y' years" 
}



**------------------------
* Subjective salary
tab subjsalary,m

recode subjsalary (-4/-1=.) (1=4) (2=3) (3=2) (4=1)

gen subjsalary_dum = (subjsalary-1)/3
label variable subjsalary_dum "0-1: Subjective salary"
label define sal_lab2 1 "It is sufficient, can save" 0 "it is not sufficient, has big problems"
label values subjsalary_dum sal_lab2
tab subjsalary_dum

**------------------------
* Gender
tab sex
tab sex, nolabel
gen female = sex
recode female (2=1) (1=0) (-2=0)
tab female

**------------------------
* age
tab age
recode age (-2/-1=.)
tab age

**------------------------
* Religion
tab religion
gen relig_dum = religion
recode relig_dum (-2=.) (-1=0) (1/12=1) (13/14=0) (15/96=1) (97=0)
tab relig_dum,m

**------------------------
* Education
tab education
tab  education, nolabel
recode education (-2=.)

sum age if education==14

*drop educ_no
gen educ_no = education
recode educ_no (6/17=0)(1/5=1)
tab educ_no

gen educ_degree = education
recode educ_degree (1/14=0) (15=1) (16/17=0)
replace educ_degree = 1 if education==14 & end_edu==-7
tab educ_degree

**------------------------
* Employment
tab employment,m
tab employment,nolabel

gen employstatus = employment
recode employstatus (-2=.) (1/3=1) (4=2) (5=3)(6=2)(7=4)
lab def empl_lbl 1 "Working" 2 "Not working" 3 "Retired" 4 "Student"
lab val employstatus empl_lbl
tab employstatus

**------------------------
* Personal economic situation
tab econsit
tab econsit, nolabel

recode econsit (-4/-1=.) (1=5) (2=4) (3=3) (4=2) (5=1)

gen econsit_dum = (econsit-1)/4
label variable econsit_dum "0-1: Personal economic situation"
label define econsit_lab2 1 "Very good" 0 "Very bad"
label values econsit_dum econsit_lab2
tab econsit_dum

pwcorr econsit_dum subjsalary_dum


***-----------------------------------------------------------*****
*generating in-sample variable

tab1 subjsalary_dum female relig_dum educ_no educ_degree employstatus econsit_dum,m

gen insample=1 if age~=. & female ~=. & subjsalary_dum ~=. & relig_dum ~=. ///
& educ_no ~=. & educ_degree ~=.  & relig_dum ~=.  & employstatus ~=. 
recode insample .=0
tab insample


**------------------------
* SAVE DATA

keep year country birthyear age fulldem1 fulldem5 howdem_dum demsat_dum bestgovt1 bestgovt2 democracybest_dum ///
 polint_dum leri_dum trust  turnout conf_president_dum-conf_union_dum ///
subjsalary_dum female relig_dum educ_no educ_degree employstatus econsit_dum insample ///
cohort5  cohort2 cohortmatch5_10 cohortmatch5_15 cohortmatch5_20 cohortmatch5_25  ///
cohortmatch2_10 cohortmatch2_12 cohortmatch2_14 cohortmatch2_16 cohortmatch2_18 cohortmatch2_20

 gen data = 1
 lab def data_lab 1"LB" 2"WVS" 3"ISSP" 4"AB"
 lab val data data_lab
 
save "DataPrep/temp/Latinobarometer_ForMerge", replace



*-----------------------------------------------------------------------------
**** WVS
*-----------------------------------------------------------------------------

use "WVS/wvs_all_merged.dta", clear

do "/Users/aneundorf/Dropbox/Legacy of authoritarian regimes data/Do files/Label_Cntry.do"

/*label define countrylab 32 "Argentina" 76 "Brazil" 152 "Chile" 170 "Colombia" ///
	214 "Dominican Republic" 218 "Ecuador" 222 "El Salvador" 320 "Guatemala" ///
	484 "Mexico" 604 "Peru" ///
	858 "Uruguay" 862 "Venezuela" 780 "Trinidad & Tobago"*/
label values country countrylab
drop if country==.

** Recode Variables

* Birthyear
set more off
tab X002
tab X002, nolabel
gen birthyear = X002
recode birthyear (-4/-1=.)

* year of survey
tab S020
rename S020 year

* Age
tab X003
rename X003 age
recode age (-4/-1=.)

**------------------------
* How democracy
* NOTE: Only in last wave

tab E236
rename E236 howdem
tab howdem
recode howdem (-4/-1=.)

gen howdem_dum = (howdem-1)/9
tab howdem_dum
lab var howdem_dum "0-1: Assess how democratic [country] is"
lab def howdem_lbl 0"completly undemcartic" 1"Completley democratic"
lab val howdem_dum howdem_lbl


**------------------------
* Democracic satisfaction

tab E110
rename E110 demsat
tab demsat
recode demsat (-4/-1=.) (1=4) (2=3) (3=2) (4=1)

gen demsat_dum = (demsat-1)/3
lab var demsat_dum "0-1: Satisfaction with democarcy" 
label define sat_lab1 1 "very satisfied" 0 "not at all satisfied"
label values demsat_dum sat_lab1
tab demsat_dum


**------------------------
* Democarcy best form of gov
tab E123
rename E123 democracybest
tab democracybest
recode democracybest (-4/-1=.) (1=4) (2=3) (3=2) (4=1)

gen democracybest_dum = (democracybest-1)/3
label variable democracybest_dum "0-1: Democracy may have problems but it is the best system of govt"
label define agree_lab2 1 "agree" 0 "disagree"
label values democracybest_dum agree_lab2
tab democracybest_dum



**------------------------
* Political interest
tab E023
rename E023 polinterest
tab polinterest
recode polinterest (-4/-1=.) (1=4) (2=3) (3=2) (4=1)

gen polint_dum = (polinterest-1)/3
label variable polint_dum "0-1: Political interest"
label define int_lab2 1 "very" 0 "not at all"
label values polint_dum int_lab2
tab polint_dum


**------------------------
* Turnout
tab E257
rename E257 turnout

tab turnout
recode turnout (-5/-1=.) 
tab turnout


**------------------------
* Confidence in institutions

rename E069_07 conf_parl
rename E069_17 conf_judic
rename E069_12 conf_party
rename E069_02 conf_milit
rename E069_08 conf_admin
rename E069_11 conf_gov
rename E069_06 conf_police
rename E069_04 conf_media
rename E069_05 conf_union


label define conf_lab2 1 "lot" 0 "no trust"

foreach i in  gov  parl judic party milit admin police media union {
recode conf_`i' (-4/-1=.) (1=4) (2=3) (3=2) (4=1)
gen conf_`i'_dum = (conf_`i'-1)/3
label variable conf_`i'_dum "0-1: Confidence in `i'"
label values conf_`i'_dum conf_lab2
tab conf_`i'_dum
}

**------------------------
* Interpersonal trust
tab A165
rename A165 trust

tab trust
recode trust (-4/-1=.) (2=0) 

label define trust_lab1 1 " Most people can be trusted" 0 "one can never be too careful when dealing with others"
label values trust trust_lab1


**------------------------
* Left-right
tab E033
rename E033 leri
tab leri
recode leri (-4/-1=.)

gen leri_dum = (leri-1)/9
tab leri_dum
lab var leri_dum "0-1: Left-Right self-placement"
lab def leri_lbl1 0"Left" 1"Right"
lab val leri_dum leri_lbl1
tab leri_dum


keep year country age  howdem_dum demsat_dum democracybest_dum ///
 polint_dum leri_dum trust birthyear turnout conf_gov_dum-conf_union_dum

 gen data = 2
 lab def data_lab 1"LB" 2"WVS" 3"ISSP" 4"AB"
 lab val data data_lab
 
save "Analysis/WVS_ForMerge.dta", replace


**------------------------------------------------
** MERGE DATA

use "DataPrep/temp/Latinobarometer_ForMerge", clear
append using "Analysis/WVS_ForMerge.dta"

tab data
tab country

drop if country==780 // Dropping Trinidad & Tabago due to insufficient N of obs and years

*** Data comparability tests

ttest turnout if year==2006 & country==32, by(data) // not significant in Argentina
ttest turnout if year==2006 & country==76, by(data) // significant in Brazil

ttest trust if year==1996 & country==152, by(data) // boarderline significant in Chile
ttest trust if year==1996 & country==484, by(data) //  significant in Mexico



save "DataPrep/Latinamerican_data", replace


**------------------------------------------------
** FIGURES

sort birthyear 

* Turnout
egen turnout_cohort = mean(turnout), by(birthyear country)
twoway lpoly turnout_cohort birthyear if birthyear>1920, by(country) ///
ytitle("Turnout [0=no; 1=yes]") xtitle("Birth year") ylabel(0(0.2)1,nogrid)   ///
scheme(s2mono) graphregion(fcolor(white)) note(" ") 
graph export "/Users/aneundorf/Dropbox/Project_Regimes/Analysis/LatinAmerica/Graphs/DescribtiveGraphs_DV/turnout_Cohort.pdf",  replace


* Left-Right
egen leri_dum_cohort = mean(leri_dum), by(birthyear country)
twoway lpoly leri_dum_cohort birthyear if birthyear>1920, by(country) ///
ytitle("Left-Right [0=Left; 1=Right]") xtitle("Birth year") ylabel(0(0.2)1,nogrid)   ///
scheme(s2mono) graphregion(fcolor(white)) note("Data: WVS") yline(0.5, lp(dash) lc(gs9))
graph export "/Users/aneundorf/Dropbox/Project_Regimes/Analysis/LatinAmerica/Graphs/DescribtiveGraphs_DV/Leri_Cohort.pdf",  replace


* Pol interest
egen polinterest_cohort = mean(polinterest), by(birthyear country)
twoway lpoly polinterest_cohort birthyear if birthyear>1920, by(country) ///
ytitle("Political interest [1=very; 4=not at all]") xtitle("Birth year")  ylabel(,nogrid)   ///
scheme(s2mono) graphregion(fcolor(white)) note(" ")
graph export "/Users/aneundorf/Dropbox/Project_Regimes/Analysis/LatinAmerica/Graphs/DescribtiveGraphs_DV/polinterest_Cohort.pdf",  replace

* Strong leader better than parliament
egen stronglead_cohort = mean(stronglead), by(birthyear country)
twoway lpoly stronglead_cohort birthyear if birthyear>1920, by(country) ///
ytitle("Better to have a strong leader to decide things" "[1=agree; 4=disagree]") xtitle("Birth year")  ylabel(,nogrid)   ///
scheme(s2mono) graphregion(fcolor(white)) note("")
graph export "/Users/aneundorf/Dropbox/Project_Regimes/Analysis/LatinAmerica/Graphs/DescribtiveGraphs_DV/stronglead_Cohort.pdf",  replace

* Democarcy best form of gov
egen democracybest_cohort = mean(democracybest), by(birthyear country)
twoway lpoly democracybest_cohort birthyear if birthyear>1920, by(country) ///
ytitle("Demcocracy best form of gov. [1=agree; 4=disagree]") xtitle("Birth year")  ylabel(,nogrid)   ///
scheme(s2mono) graphregion(fcolor(white)) note("")
graph export "/Users/aneundorf/Dropbox/Project_Regimes/Analysis/LatinAmerica/Graphs/DescribtiveGraphs_DV/democracybest_Cohort.pdf",  replace

* Which best form of gov
egen bestgov_dem_cohort = mean(bestgovt1), by(birthyear country)
egen bestgov_auth_cohort = mean(bestgovt2), by(birthyear country)

twoway lpoly bestgov_dem_cohort birthyear if birthyear>1920, by(country) ///
ytitle("Demcrarcy is best form of government [0=no; 1=yes]") xtitle("Birth year") yline(0.5, lp(dash) lc(gs9)) ylabel(0(0.2)1,nogrid)   ///
scheme(s2mono) graphregion(fcolor(white)) note("")
graph export "/Users/aneundorf/Dropbox/Project_Regimes/Analysis/LatinAmerica/Graphs/DescribtiveGraphs_DV/bestgovt_dem_Cohort.pdf",  replace

twoway lpoly bestgov_auth_cohort birthyear if birthyear>1920, by(country) ///
ytitle("Authoritarianism is best form of government [0=no; 1=yes]") xtitle("Birth year") yline(0.5, lp(dash) lc(gs9)) ylabel(0(0.2)1,nogrid)   ///
scheme(s2mono) graphregion(fcolor(white)) note("")
graph export "/Users/aneundorf/Dropbox/Project_Regimes/Analysis/LatinAmerica/Graphs/DescribtiveGraphs_DV/bestgovt_auth_Cohort.pdf",  replace

* Government good to all people
egen govgood_cohort = mean(govgood), by(birthyear country)
twoway lpoly govgood_cohort birthyear if birthyear>1920, by(country) ///
ytitle("Government good for all [0=no; 1=yes]") xtitle("Birth year") yline(0.5, lp(dash) lc(gs9)) ylabel(,nogrid)   ///
scheme(s2mono) graphregion(fcolor(white)) note("")
graph export "/Users/aneundorf/Dropbox/Project_Regimes/Analysis/LatinAmerica/Graphs/DescribtiveGraphs_DV/govgood_Cohort.pdf",  replace

* Government approval
egen govtapprove_cohort = mean(govtapprove), by(birthyear country)
twoway lpoly govtapprove_cohort birthyear if birthyear>1920, by(country) ///
ytitle("Approve government performance [0=no; 1=yes]") xtitle("Birth year") yline(0.5, lp(dash) lc(gs9)) ylabel(,nogrid)   ///
scheme(s2mono) graphregion(fcolor(white)) note("")
graph export "/Users/aneundorf/Dropbox/Project_Regimes/Analysis/LatinAmerica/Graphs/DescribtiveGraphs_DV/govtapprove_Cohort.pdf",  replace

* Democracy solves problems
egen solvesprob_cohort = mean(solvesprob), by(birthyear country)
twoway lpoly solvesprob_cohort birthyear if birthyear>1920, by(country) ///
ytitle("Democracy solves problems [0=no; 1=yes]") xtitle("Birth year") yline(0.5, lp(dash) lc(gs9)) ylabel(,nogrid)   ///
scheme(s2mono) graphregion(fcolor(white)) note("")
graph export "/Users/aneundorf/Dropbox/Project_Regimes/Analysis/LatinAmerica/Graphs/DescribtiveGraphs_DV/solvesprob_Cohort.pdf",  replace


* Democracic satisfaction
egen demsat_cohort = mean(demsat), by(birthyear country)
twoway lpoly demsat_cohort birthyear if birthyear>1920, by(country) ///
ytitle("Satisfaction with democracy [1=very; 4=not at all]") xtitle("Birth year")  ///
scheme(s2mono) graphregion(fcolor(white)) 
graph export "/Users/aneundorf/Dropbox/Project_Regimes/Analysis/LatinAmerica/Graphs/DescribtiveGraphs_DV/Demsat_Cohort.pdf",  replace


* How democracic
egen howdem_cohort = mean(howdem), by(birthyear country)
twoway lpoly howdem_cohort birthyear if birthyear>1920, by(country) ///
ytitle("How democartic is country [1=not; 10=fully]") xtitle("Birth year")  ///
scheme(s2mono) graphregion(fcolor(white)) 
graph export "/Users/aneundorf/Dropbox/Project_Regimes/Analysis/LatinAmerica/Graphs/DescribtiveGraphs_DV/How_dem_Cohort.pdf",  replace


* Full democracy
egen dkdem_cohort = mean(fulldem5), by(country birthyear)
egen fulldem_cohort = mean(fulldem1), by(country birthyear)

twoway lpoly dkdem_cohort birthyear if birthyear>1920, by(country) ///
ytitle("Do not know what democracy is (proportion)") xtitle("Birth year")  ///
scheme(s2mono) graphregion(fcolor(white)) 
graph export "/Users/aneundorf/Dropbox/Project_Regimes/Analysis/LatinAmerica/Graphs/DescribtiveGraphs_DV/DK_democarcy_Cohort.pdf",  replace

twoway lpoly fulldem_cohort birthyear if birthyear>1920, by(country) ///
ytitle("Country is fully democartic (proportion)") xtitle("Birth year")  ///
scheme(s2mono) graphregion(fcolor(white)) 
graph export "/Users/aneundorf/Dropbox/Project_Regimes/Analysis/LatinAmerica/Graphs/DescribtiveGraphs_DV/Full_democarcy_Cohort.pdf",  replace

