** --------------------------------------------------------------------------
** RECODING OF DATA: Afrobarometer

clear all
cd "/Users/aneundorf/Dropbox/Legacy of authoritarian regimes data/"
*cd "/Users/ldzan/Dropbox/Legacy of authoritarian regimes data/"
*cd "C:/Users/Rosie/Dropbox/Research/legacy of authoritarian regimes/Legacy of authoritarian regimes data/"

** Get data
use "Data for harmonisation/Afrobarometer.dta", clear

**------------------------
* Democracic satisfaction

tab demsat_afb
tab demsat_afb, nolabel

tab demsat_afb if year<2002

tab country if demsat_afb ==0

*** change of number of categories after wave 1


recode demsat_afb (-4/-1=.) (0=1)(1=5) (2=4) (3=3) (4=2) (5=1) if year<2002, gen(demsat_wave1)
recode demsat_afb (-4/-1=.) (0=1)(1=4) (2=3) (4=2) (5=1) if year>2002, gen(demsat_wave2)
tab demsat_wave2,m

gen demsat = ((demsat_wave2-1)/3)*100
lab var demsat "0-100: Satisfaction with democarcy" 
label define sat_lab1 100 "very satisfied" 0 "not at all satisfied"
label values demsat sat_lab1
tab demsat

replace demsat = 0 if demsat_wave1==1
replace demsat = 25 if demsat_wave1==2
replace demsat = 50 if demsat_wave1==3
replace demsat = 75 if demsat_wave1==4
replace demsat = 100 if demsat_wave1==5

gen demsat_cat = 4
replace demsat_cat = 5 if year<2002
lab var demsat_cat "Nr of categories: Satisfaction with democarcy"  
tab demsat_cat

tab year if demsat!=.


**------------------------
* Strong leader 

tab rejdic
tab rejdic, nolabel
recode rejdic  (6/9=.) 

gen strongleader = ((rejdic-1)/4)*100
lab var strongleader "0-100: Strong leader better than parliament and elections "
label define agree_lab1 100 "completly agree" 0 "completly disagree" 
label values strongleader agree_lab1
tab strongleader

gen strongleader_cat = 5
lab var strongleader_cat "Nr of categories: Strong leader better"  

tab year if strongleader!=.


**------------------------
* Confidence in institutions

rename conf_milit_afb conf_milit
rename conf_press_afb conf_media
rename conf_police_afb conf_police
rename conf_parl_afb conf_parl
rename conf_rule_afb conf_gov
rename conf_judic_afb conf_judic
rename conf_president_afb conf_president

foreach i in  gov president parl judic  milit  police media   {
tab conf_`i'
tab conf_`i', nolabel
}

label define conf_lab2 100 "A lot" 0 "No trust"

foreach i in  gov president parl judic  milit  police media  {
recode conf_`i' (-4/-1=.) (1=4) (2=3) (3=2) (4=1)
gen trust_`i' = ((conf_`i'-1)/3)*100
label variable trust_`i' "0-100: Confidence in `i'"
label values trust_`i' conf_lab2
tab trust_`i'
gen trust_`i'_cat=4
}


**------------------------
* Turnout

tab turnout_afb
tab turnout_afb, nolabel
recode turnout_afb  (-5/-1=.), gen(turnout)
lab var turnout "0-1: Voted in last nat. election"
lab def trnlbl1 1 "Voted" 0 "Did not vote"
lab val turnout trnlbl1
tab turnout

**------------------------
* Political interest

tab1 polinterest_afb polinterest2_afb // polinterest2_afb is only for Wave 2 = 2004
tab polinterest_afb,nolabel

recode polinterest_afb (-4/-1=.) (1=4) (2=3) (3=2) (4=1)

gen polint = ((polinterest_afb-1)/3)*100
replace polint = 0 if polinterest2_afb == 3 & year==2004
replace polint = 50 if polinterest2_afb == 2 & year==2004
replace polint = 100 if polinterest2_afb == 1 & year==2004

label variable polint "0-100: Political interest"
label define int_lab2 100 "very interested" 0 "not at all interested"
label values polint int_lab2
tab polint


gen polint_cat = 4
replace polint_cat=3 if year==2004
tab polint_cat

**------------------------
* Gender equality

tab women_leaders_afb
tab women_leaders_afb,nolabel

recode women_leaders_afb (-5/-1=.) 
gen women_lead = ((women_leaders_afb-1)/4)*100
label variable women_lead "0-100: Men NOT better politcal leaders"
label define men_lab2 100 "Men NOT better leaders" 0 "Men better leaders"
label values women_lead men_lab2
tab women_lead

gen women_lead_cat = 5

**------------------------
* Independent variables

* gender
generate female = female_afb 
recode female (-1 = .) (0 = 0) (1 = 1) 
label variable female "gender: female" 
label define female 0 "man" -1 "Missing" 1 "woman" 
label value female female 
tab female female_afb

* religion
generate religion = religion_afb 
recode religion (-4 = .) (-2 = .) (-1 = .) (1 = 1) (2 = 3) (3 = 2 ) (4 = 1) (5 = 3) (6 = 3) (7 = 1) ///
	(8 = 1) (9 = 3) (10 = 0) 
label variable religion "Religious: yes/no + denomination" 
label define religion 0 "not religious " 2 "Muslim " 1 "Christian " 3 "Other " -1 "Missing "
label value religion religion 
tab religion religion_afb

* education - categorical
drop educ
generate educ = education_afb
recode educ (-4 = .) (-2 = .) (-1 = .) (1 = 1) (2 = 1) (3 = 2) (4 = 3) 
label variable educ "education: categorical" 
label define educlab 2 "secondary " 1 "primary or less " -1 "Missing " 3 "post-secondary " 
label value educ educlab
tab educ education_afb

* employment status
generate employment = employment_afb 
recode employment (-4 = .) (-2 = .) (-1 = .) (1 = 2 ) (2 = 1) (3 = 1) 
label variable employment "employment status" 
label define employment -1 "Missing " 2 "Unemployed " 1 "Working " 
label value employment employment 
tab employment employment_afb


** Ethnicity 

tab ethni
tab ethni, nolabel

recode ethni (-1=.)(1=2)(2=1)(3/6=3),gen(race)
lab var race "3-cat race variable"
lab def racelbl 1"White" 2"Black" 3"Other"
lab val race racelbl 
tab race
tab race if country==710

********* Reduce dataset to only harmonised variables
keep country year data age birth demsat demsat_cat ///
strongleader strongleader_cat trust_gov-trust_media_cat turnout polint polint_cat  ///
women_lead women_lead_cat female religion educ employment income_10 income_5 race


**** Save prepared data
save "MergedData/temp/Afrobarometer_recoded.dta", replace
