** --------------------------------------------------------------------------
** RECODING OF DATA: Asianbarometer

clear all
cd "/Users/aneundorf/Dropbox/Legacy of authoritarian regimes data/"
*cd "/Users/ldzan/Dropbox/Legacy of authoritarian regimes data/"

*cd "C:/Users/Rosie/Dropbox/Research/legacy of authoritarian regimes/Legacy of authoritarian regimes data/"


** Get data
use "Data for harmonisation/Asianbarometer.dta"

**------------------------
* Democracic satisfaction

tab demsat
tab demsat, nolabel

recode demsat (-3/-2=.) (1=4) (2=3) (3=2) (4=1)

gen demsat = ((demsat-1)/3)*100
lab var demsat "0-100: Satisfaction with democarcy" 
label define sat_lab1 100 "very satisfied" 0 "not at all satisfied"
label values demsat sat_lab1
tab demsat

gen demsat_cat = 4
tab demsat_cat
lab var demsat_cat "Nr of categories: Satisfaction with democarcy" 

tab year if demsat!=.

**------------------------
* Democracy best 

tab democracybest_anb
tab democracybest_anb, nolabel

recode democracybest_anb (-4/-1=.) (1=4) (2=3) (3=2) (4=1)

gen democbest = ((democracybest_anb-1)/3)*100
lab var democbest "0-100: Democarcy best form of government" 
label define agree_lab1 100 "completly agree" 0 "completly disagree"
label values democbest agree_lab1
tab democbest

gen democbest_cat = 4
lab var democbest_cat "Nr of categories: Democarcy best form of government" 

tab year if democbest_cat!=.


**------------------------
* Strong leader 

tab strongleader_anb
tab strongleader_anb, nolabel
recode strongleader_anb (-4/-1=.) (1=4) (2=3) (3=2) (4=1)

gen strongleader = ((strongleader_anb-1)/3)*100
lab var strongleader "0-100: Strong leader better than parliament and elections " 
label values strongleader agree_lab1
tab strongleader

gen strongleader_cat = 4
lab var strongleader_cat "Nr of categories: Strong leader better"  

tab year if strongleader!=.

**------------------------
* Confidence in institutions

rename conf_milit_anb conf_milit
rename conf_news_anb conf_media
rename conf_police_anb conf_police
rename conf_parl_anb conf_parl
rename conf_admin_anb conf_admin
rename conf_gov_anb conf_gov
rename conf_party_anb conf_party
rename conf_judic_anb conf_judic

foreach i in  gov  parl judic party milit admin police media  {
tab conf_`i'
tab conf_`i', nolabel
}

label define conf_lab2 100 "A lot" 0 "No trust"

foreach i in  gov  parl judic party milit admin police media  {
recode conf_`i' (-4/-1=.) 
gen trust_`i' = ((conf_`i'-1)/3)*100
label variable trust_`i' "0-100: Confidence in `i'"
label values trust_`i' conf_lab2
tab trust_`i'
gen trust_`i'_cat=4
}


**------------------------
* Turnout

tab turnout_anb
tab turnout_anb, nolabel
recode turnout_anb  (-5/-1=.) (-6=0), gen(turnout)
lab var turnout "0-1: Voted in last nat. election"
lab def trnlbl1 1 "Voted" 0 "Did not vote"
lab val turnout trnlbl1
tab turnout

**------------------------
* Political interest

tab polinterest_anb
tab polinterest_anb,nolabel

recode polinterest_anb (-4/-1=.) 

gen polint = ((polinterest_anb-1)/3)*100
label variable polint "0-100: Political interest"
label define int_lab2 100 "very interested" 0 "not at all interested"
label values polint int_lab2
tab polint

gen polint_cat = 4

**------------------------
* Independent variables

* gender
generate female = female_anb 
recode female (0 = 0) (1 = 1) 
label variable female "gender: female" 
label define female 0 "man" 1 "woman" -1 "Missing" 
label value female female 
tab female female_anb

* social class
generate class = status_anb 
recode class (1 = 1) (2 = 1) (3 = 2) (4 = 2) (5 = 3) (6 = 3) (7 = 4) (8 = 4) (9 = 5) ///
	(10 = 5) (-1 = .) (-2 = .) (-3 = .) (1 = 1) (2 = 1) (3 = 2) (4 = 2) (5 = 3) (6 = 3) ///
	(7 = 4) (8 = 4) (9 = 5) (10 = 5) (-1 = .) (-2 = .) (-3 = .) (1 = 1) (2 = 1) (3 = 2) (4 = 2) (5 = 3) (6 = 3) (7 = 4) (8 = 4) (9 = 5) (10 = 5) (-1 = .) (-2 = .) (-3 = .) 
label variable class "social class" 
label define class 5 "High/Upper " 1 "low " 4 "Middle class " 2 "working class " ///
	3 "low middle/high working " -1 "Missing " 
label value class class 
tab class status_anb

* social class from wave 1 - needs to be added to charmstats
replace class = 5 if class_wave1==1
replace class = 4 if class_wave1==2
replace class = 3 if class_wave1==3
replace class = 2 if class_wave1==4
replace class = 1 if class_wave1==5

* marital status
generate married = marstat_anb 
recode married (-3 = .) (-2 = .) (1 = 1) (2 = 1) (3 = 0) (4 = 0) (5 = 0) 
label variable married "marital status" 
label define married 1 "Married or living with partner " -1 "Missing " 0 "Not married " 
label value married married 
tab married marstat_anb

* religion
generate religion = relig_anb 
recode religion (-3 = .) (-2 = .) (1 = 3) (2 = 3) (3 = 3) (4 = 1) (5 = 3) (6 = 3) (7 = 2 ) ///
	(8 = 1) (9 = 1) (10 = 3) (11 = 0) (12 = 3) (13 = 3) (14 = 3) (15 = 1) 
label variable religion "Religious: yes/no + denomination" 
label define religion 0 "not religious " 2 "Muslim " 1 "Christian " 3 "Other " -1 "Missing " 
label value religion religion 
tab religion relig_anb

* education - categorical
generate educ = education_anb 
recode educ (-3 = .) (-2 = .) (0 = 1) (1 = 1) (2 = 1) (3 = 2) (4 = 2) (5 = 2) (6 = 2) (7 = 3) ///
	(8 = 3) (9 = 3) (10 = 0) 
label variable educ "education: categorical" 
label define educ 2 "secondary " 1 "primary or less " -1 "Missing " 3 "post-secondary " 0 "Other " 
label value educ educ 
tab educ education_anb

* employment status
generate employment = employed_anb 
recode employment (-4 = .) (-3 = .) (1 = 1) (2 = 2 )
label variable employment "employment status" 
label define employment  -1 "Missing " 2 "Unemployed " 1 "Working " 
label value employment employment 
tab employment employed_anb

* financial satisfaction
tab finan_satis_anb, nol
gen econsit = ((finan_satis_anb-1)/4)*100 if finan_satis_anb >=1
label var econsit "financial satisfaction"
label define sat_lab2 100 "very satisfied" 0 "not at all satisfied"
label values econsit sat_lab2


********* Reduce dataset to only harmonised variables
keep country year data age birth demsat demsat_cat democbest democbest_cat ///
strongleader strongleader_cat trust_gov-trust_media_cat turnout polint polint_cat ///
female class married religion educ employment income_5 econsit // income_10



**** Save prepared data
save "MergedData/temp/Asianbarometer_recoded.dta", replace
