** --------------------------------------------------------------------------
** RECODING OF DATA: ESS

clear all
*cd "/Users/aneundorf/Dropbox/Legacy of authoritarian regimes data/"
*cd "/Users/ldzan/Dropbox/Legacy of authoritarian regimes data/"

cd "C:/Users/Rosie/Dropbox/Research/legacy of authoritarian regimes/Legacy of authoritarian regimes data/"


** Get data
use "Data for harmonisation/ESS.dta"


**------------------------
* Democracic satisfaction

tab stfdem
tab stfdem, nolabel

recode stfdem (77/99=.)

gen demsat = (stfdem/10)*100
lab var demsat "0-100: Satisfaction with democarcy" 
label define sat_lab1 100 "very satisfied" 0 "not at all satisfied"
label values demsat sat_lab1
tab demsat

gen demsat_cat = 11
tab demsat_cat
lab var demsat_cat "Nr of categories: Satisfaction with democarcy" 

tab year if demsat!=.

**------------------------
* Confidence in institutions

rename trstplc conf_police
rename trstprl conf_parl
rename trstlgl conf_judic

foreach i in   parl judic police  {
tab conf_`i'
tab conf_`i', nolabel
}

label define conf_lab2 100 "A lot" 0 "No trust"

foreach i in  parl judic police  {
recode conf_`i' (77/99=.) 
gen trust_`i' = ((conf_`i')/10)*100
label variable trust_`i' "0-1: Confidence in `i'"
label values trust_`i' conf_lab2
tab trust_`i'
gen trust_`i'_cat=11
}


**------------------------
* Turnout

tab vote
tab vote, nolabel

recode vote (1=1)(2/3=0)(7/9=.), gen(turnout)
lab var turnout "0-1: Voted in last nat. election"
lab def trnlbl1 1 "Voted" 0 "Did not vote"
lab val turnout trnlbl1
tab turnout

**------------------------
* Political interest

tab polintr
tab polintr,nolabel

recode polintr (7/9=.) (1=4) (2=3) (3=2) (4=1)

gen polint = ((polintr-1)/3)*100
label variable polint "0-100: Political interest"
label define int_lab2 100 "very interested" 0 "not at all interested"
label values polint int_lab2
tab polint

gen polint_cat = 4

**-------------------------
* Independent variables
* gender
generate female = gndr 
recode female (1 = 0) (2 = 1) (9 = .) 
label variable female "gender: female" 
label define female 0 "man" -1 "Missing " 1"woman " 
label value female female 
tab female gndr

* marital status
generate married = marstat_ess 
recode married (1 = 1) (2 = 0) (3 = 0) (4 = 0) (5 = 0) 
label variable married "marital status" 
label define married 1 "Married or living with partner " 0 "Not married " 
label value married married 
tab married marstat_ess

* religion
generate religion = rlgdnm 
recode religion (1 = 1) (2 = 1) (3 = 1) (4 = 1) (5 = 3) (6 = 2 ) (7 = 3) (8 = 3) (66 = .) ///
	(77 = .) (99 = .) (0 = 0) (0 = 0) 
label variable religion "Religious: yes/no + denomination" 
label define religion 0 "not religious " 2 "Muslim " 1 "Christian " 3 "Other " -1 "Missing "
label value religion religion 
tab religion rlgdnm

* education - categorical
generate educ = eisced 
recode educ (0 = .) (1 = 1) (2 = 2) (3 = 2) (4 = 2) (5 = 2) (6 = 3) (7 = 3) (55 = 0) (77 = .) ///
	(88 = .) (99 = .) 
label variable educ "education: categorical" 
label define educ 2 "secondary " 1 "primary or less " 0 "Other " 3 "post-secondary " -1 "Missing " 
label value educ educ 
tab educ eisced

* education - years of education
tab eduyrs
tab eduyrs, nolabel

generate educ_yr = eduyrs 
recode educ_yr (77/99=.) (0/6 = 1) (7/12 = 2) (13/56 = 3) 
label variable educ_yr "education: based on years" 
label value educ_yr educ 

tab educ_yr educ
tab educ_yr if educ==.

replace educ = educ_yr if educ==.
drop educ_yr

tab educ,m

* employment status
tab pdwrk
tab pdwrk, nolabel

generate employment = pdwrk 
recode employment (1 = 1) (0 = 2 )
label variable employment "employment status" 
label define employment -1 "Missing " 2 "Unemployed " 1 "Working " 
label value employment employment 
tab employment pdwrk



********* Reduce dataset to only harmonised variables
keep country year data age birth demsat demsat_cat trust_parl-trust_police_cat eastgerman ///
turnout polint polint_cat female married religion educ employment income_10 income_5 father_worker


**** Save prepared data
save "MergedData/temp/ESS_recoded.dta", replace
