** --------------------------------------------------------------------------
** RECODING OF DATA: Eurobarometer

clear all
cd "/Users/aneundorf/Dropbox/Legacy of authoritarian regimes data/"
*cd "/Users/ldzan/Dropbox/Legacy of authoritarian regimes data/"
*cd "C:/Users/Rosie/Dropbox/Research/legacy of authoritarian regimes/Legacy of authoritarian regimes data/"


** Get data
use "Data for harmonisation/Eurobarometer.dta"


**------------------------
* Democracic satisfaction

tab satisdmo
tab satisdmo, nolabel

recode satisdmo (8/9=.) (1=4) (2=3) (3=2) (4=1)

gen demsat = ((satisdmo-1)/3)*100
lab var demsat "0-100: Satisfaction with democarcy" 
label define sat_lab1 100 "very satisfied" 0 "not at all satisfied"
label values demsat sat_lab1
tab demsat

gen demsat_cat = 4
tab demsat_cat
lab var demsat_cat "Nr of categories: Satisfaction with democarcy" 

tab year if demsat!=.

**------------------------
* Turnout 

tab1 lastvote voteint

*tab year E257 
*tab year E264


* Actual turnout
tab lastvote
tab lastvote, nolabel

recode lastvote (0=.) (1/990=1)(995/996=0)(997/999=.), gen(turnout)
lab var turnout "0-1: Voted in last nat. election"
lab def trnlbl1 1 "Voted" 0 "Did not vote"
lab val turnout trnlbl1
tab turnout

* Turnout propensity
tab voteint
tab voteint, nolabel

recode voteint (0=.) (1/990=1)(995/996=0)(997=.)(999=.) (998=0), gen(turnout_prob)
lab var turnout_prob "Probability to turnout"
lab def trnlbl 1 "probable turnout" 0 "unprobable turnout"
lab val turnout_prob trnlbl
tab turnout_prob
tab voteint turnout_prob

**------------------------
* Political interest

tab polint
tab polint,nolabel

recode polint (7/9=.) (1=4) (2=3) (3=2) (4=1), gen(polint_r)
drop polint

gen polint = ((polint_r-1)/3)*100
label variable polint "0-100: Political interest"
label define int_lab2 100 "very interested" 0 "not at all interested"
label values polint int_lab2
tab polint

gen polint_cat = 4

**-------------------------
* Independent variables
* gender
generate female = sex 
recode female (1 = 0) (2 = 1) (8 = .) (9 = .) 
label variable female "gender: female" 
label define female 0 "man" -1 "Missing" 1 "woman" 
label value female female 
tab female sex

* social class
generate class = soclass 
recode class (1 = 1) (2 = 2) (3 = 3) (4 = 4) (5 = 5) (6 = -1) (7 = -1) (98 = .) (99 = .) 
label variable class "social class" 
label define class 5 "High/Upper " 1 "low " 4 "Middle class " 2 "working class " 3 "low middle/high working " -1 "Missing " 
label value class class 
tab class soclass

* marital status
generate married2 = married 
recode married2 (1 = 0) (2 = 1) (3 = 1) (4 = 0) (5 = 0) (6 = 0) (9 = 0) (10 = .) (98 = .) (99 = .) 
label variable married2 "marital status" 
label define married 1 "Married or living with partner " -1 "Missing " 0 "Not married " 
label value married2 married
tab married married2
drop married
rename married2 married

* religion
generate religion = denom 
recode religion (110 = 1) (120 = 1) (121 = 1) (122 = 1) (123 = 1) (124 = 1) (125 = 1) (126 = 1) ///
	(130 = 1) (131 = 1) (141 = 1) (142 = 1) (143 = 1) (144 = 1) (145 = 1) (201 = 3) (202 = 3) ///
	(203 = 3) (204 = 2 ) (980 = 3) (990 = 0) (998 = .) (999 = .) 
label variable religion "Religious: yes/no + denomination" 
label define religion 0 "not religious " 2 "Muslim " 1 "Christian " 3 "Other " -1 "Missing " 
label value religion religion
tab religion denom 

* employment status
generate employment = occup 
recode employment (110 = 1) (111 = 1) (112 = 1) (120 = 1) (130 = 1) (131 = 1) (132 = 1) (210 = 1) ///
	(220 = 1) (230 = 1) (310 = 1) (311 = 1) (312 = 1) (320 = 1) (321 = 1) (322 = 1) (410 = 1) ///
	(411 = 1) (412 = 1) (413 = 1) (500 = 2 ) (510 = 2 ) (520 = 2 ) (521 = 2 ) (522 = 2 ) (530 = 2 ) ///
	(540 = 2 ) (998 = .) (999 = .) 
label variable employment "employment status" 
label define employment -1 "Missing " 2 "Unemployed " 1 "Working " 
label value employment employment 
tab employment occup


* education
tab educ
tab educ, nolabel
recode educ (1 = 1) (2/7 = 2) (8/9 = 3) (98/99 = .) , gen(educ_yr)
replace educ_yr = 2 if age<19 & educ_yr==10
replace educ_yr = 3 if age>18 & educ_yr==10

label variable educ_yr "education: based on years" 
label define educ_yr 2 "secondary " 1 "primary or less " 0 "Other " 3 "post-secondary " -1 "Missing " 
label value educ_yr educ_yr 

tab educ_yr,m

********* Reduce dataset to only harmonised variables
keep country year data age birth demsat demsat_cat turnout turnout_prob ///
polint polint_cat female class married religion employment income_10 income_5 educ_yr


**** Save prepared data
save "MergedData/temp/Eurobarometer_recoded.dta", replace
