** --------------------------------------------------------------------------
** RECODING OF DATA: ISSP

clear all
*cd "/Users/aneundorf/Dropbox/Legacy of authoritarian regimes data/"
*cd "/Users/ldzan/Dropbox/Legacy of authoritarian regimes data/"
cd "C:/Users/Rosie/Dropbox/Research/legacy of authoritarian regimes/Legacy of authoritarian regimes data/"


** Get data
use "Data for harmonisation/ISSP.dta"


**------------------------
* Confidence in institutions

rename confparl_issp conf_parl
rename confjud_issp conf_judic
rename confpub_issp conf_admin
rename confchurch_issp conf_church
rename govtrust_issp conf_gov

foreach i in  gov  parl judic  admin  church {
tab conf_`i'
tab conf_`i', nolabel
}

label define conf_lab2 100 "A lot" 0 "No trust"

foreach i in  gov  parl judic  admin  church {
recode conf_`i' (-5/-1=.) (1=5) (2=4) (3=3) (4=2) (5=1)
gen trust_`i' = ((conf_`i'-1)/4)*100
label variable trust_`i' "0-100: Confidence in `i'"
label values trust_`i' conf_lab2
tab trust_`i'
gen trust_`i'_cat=5
}

**------------------------
* Turnout

tab turnout_issp
tab turnout_issp, nolabel
rename turnout_issp turnout

**------------------------
* Political interest

tab polinterest_issp
tab polinterest_issp,nolabel

recode polinterest_issp (-5/-1=.) (1=4) (2=3) (3=2) (4=1)

gen polint = ((polinterest_issp-1)/3)*100
label variable polint "0-100: Political interest"
label define int_lab2 100 "very interested" 0 "not at all interested"
label values polint int_lab2
tab polint

gen polint_cat = 4

**---------------------------
* Independent variables

* gender
generate female = female_issp 
recode female (0.00 = 0) (1.00 = 1) 
label variable female "gender: female" 
label define female 0 "man" 1 "woman" -1 "Missing"
label value female female 
tab female female_issp

* social class
generate class = sclass_issp 
recode class (1.00 = 1) (2.00 = 2) (3.00 = 3) (4.00 = 4) (5.00 = 5) (6.00 = 5) 
label variable class "social class" 
label define class 5 "High/Upper " 1 "low " 4 "Middle class " 2 "working class " 3 "low middle/high working " 
label value class class
tab class sclass_issp 

* marital status
generate married = marstat_issp 
recode married (1.00 = 1) (2.00 = 0) (3.00 = 0) (4.00 = 0) (5.00 = 0) 
label variable married "marital status" 
label define married 1 "Married or living with partner " 0 "Not married " 
label value married married 
tab married marstat_issp

* religion
generate religion = religion_issp 
recode religion (1.00 = 1) (2.00 = 3) (3.00 = 2 ) (4.00 = 1) (5.00 = 3) (6.00 = 3) (7.00 = 1) ///
	(8.00 = 1) (9.00 = 3) (10.00 = 0) 
label variable religion "Religious: yes/no + denomination" 
label define religion 0 "not religious " 2 "Muslim " 1 "Christian " 3 "Other " 
label value religion religion 
tab religion religion_issp

* employment status
generate employment = employed3 
recode employment (0.00 = 2 ) (1.00 = 1) 
label variable employment "employment status" 
label define employment 2 "Unemployed " 1 "Working " 
label value employment employment 
tab employment employed3

* education
tab1 eduyears_issp education_issp

generate educ = eduyears_issp 
recode educ (1 = 1) (2 = 1) (3 = 1) (4 = 1) (5 = 1) (6 = 1) (7 = 2) (8 = 2) (9 = 2) (10 = 2) (11 = 2) ///
(12 = 2) (13 = 3) (14 = 3) (15 = 3) (16 = 3) (17 = 3) (18 = 3) (19 = 3) (20 = 3) (21 = 3) (22 = 3) ///
(23 = 3) (24 = 3) (25 = 3) (26 = 3) (27 = 3) (28 = 3) (29 = 3) (30 = 3) (31 = 3) (32 = 3) (33 = 3) ///
(34 = 3) (35 = 3) (36 = 3) (37 = 3) (38 = 3) (39 = 3) (40 = 3) (41 = 3) (42 = 3) (43 = 3) (44 = 3) ///
(45 = 3) (46 = 3) (47 = 3) (48 = 3) (49 = 3) (50 = 3) (51 = 3) (52 = 3) (53 = 3) (54 = 3) (55 = 3) ///
(56 = 3) (57 = 3) (58 = 3) (59 = 3) (60 = 3) (61 = 3) (62 = 3) (63 = 3) (64 = 3) (65 = 3) (66 = 3) ///
(67 = 3) (68 = 3) (69 = 3) (70 = 3) (71 = 3) (72 = 3) (73 = 3) (74 = 3) (75 = 3) (76 = 3) (77 = 3) ///
(78 = 3) (79 = 3) (80 = 3) (81 = 3) (82 = 3) (83 = 3) (84 = 3) (85 = 3) (86 = 3) (87 = 3) (88 = 3) ///
(89 = 3) (90 = 3) (91 = 3) (92 = 3) (93 = 3) (94 = .) (95 = 1) (96 = 2) (97 = 1) (98 = 3) (99 = 3) ///
(-1 = .) (-1 = .) 
label variable educ "education: categorical" 
label define educ 3 "post-secondary " -1 "Missing " 0 "Other " 1 "primary or less " 2 "secondary " 
label value educ edu


********* Reduce dataset to only harmonised variables
keep country year data age birth trust_gov trust_church trust_gov_cat -trust_church_cat ///
turnout polint polint_cat female class married religion employment income_10 income_5 educ

tab country
**** Save prepared data
save "MergedData/temp/ISSP_recoded.dta", replace




