** --------------------------------------------------------------------------
** RECODING OF DATA: Latinobarometer

clear all
cd "/Users/aneundorf/Dropbox/Legacy of authoritarian regimes data/"
*cd "/Users/ldzan/Dropbox/Legacy of authoritarian regimes data/"
*cd "C:/Users/Rosie/Dropbox/Research/legacy of authoritarian regimes/Legacy of authoritarian regimes data/"


** Get data
use "Data for harmonisation/Latinobarometer.dta", clear


**------------------------
* Democracic satisfaction

tab demsat_lb
tab demsat_lb, nolabel
recode demsat_lb (-4/-1=.) (1=4) (2=3) (3=2) (4=1)

gen demsat = ((demsat-1)/3)*100
lab var demsat "0-100: Satisfaction with democarcy" 
label define sat_lab1 100 "very satisfied" 0 "not at all satisfied"
label values demsat sat_lab1
tab demsat

gen demsat_cat = 4
tab demsat_cat
lab var demsat_cat "Nr of categories: Satisfaction with democarcy" 

tab year if demsat!=.


**------------------------
* Democracy best 

tab democracybest_lb
tab democracybest_lb, nolabel
recode democracybest_lb (-4/-1=.) (1=4) (2=3) (3=2) (4=1)

gen democbest = ((democracybest_lb-1)/3)*100
lab var democbest "0-100: Democarcy best form of government" 
label define agree_lab1 100 "completly agree" 0 "completly disagree"
label values democbest agree_lab1
tab democbest

gen democbest_cat = 4
lab var democbest_cat "Nr of categories: Democarcy best form of government" 

tab year if democbest_cat!=.


**------------------------
* Strong leader 

tab stronglead_lb
tab stronglead_lb, nolabel
recode stronglead_lb (-4/-1=.) (1=4) (2=3) (3=2) (4=1)

gen strongleader = ((stronglead_lb-1)/3)*100
lab var strongleader "0-100: Strong leader better than parliament and elections " 
label values strongleader agree_lab1
tab strongleader

gen strongleader_cat = 4
lab var strongleader_cat "Nr of categories: Strong leader better"  

tab year if strongleader!=.


**------------------------
* Confidence in institutions

foreach i in  gov president parl judic party milit admin police media union church {
tab conf_`i'
tab conf_`i', nolabel
}

label define conf_lab2 100 "A lot" 0 "No trust"

foreach i in  gov president parl judic party milit admin police media union church {
recode conf_`i' (-4/-1=.) (1=4) (2=3) (3=2) (4=1)
gen trust_`i' = ((conf_`i'-1)/3)*100
label variable trust_`i' "0-100: Confidence in `i'"
label values trust_`i' conf_lab2
tab trust_`i'
gen trust_`i'_cat=4
}

*pca trust_gov -trust_church, mineigen(1)

**------------------------
* Turnout

tab turnout
tab turnout, nolabel
recode turnout (-4/-1=.) (2/8=0) 
tab turnout

**------------------------
* Political interest

tab polinterest
tab polinterest,nolabel

recode polinterest (-4/-1=.) (1=4) (2=3) (3=2) (4=1)

gen polint = ((polinterest-1)/3)*100
label variable polint "0-100: Political interest"
label define int_lab2 100 "very interested" 0 "not at all interested"
label values polint int_lab2
tab polint

gen polint_cat = 4


**------------------------
* Gender equality

tab womenleader_lb
tab womenleader_lb,nolabel

recode womenleader_lb (-5/-1=.) 

gen women_lead = ((womenleader_lb-1)/3)*100
label variable women_lead "0-100: Men NOT better politcal leaders"
label define men_lab2 100 "Men NOT better leaders" 0 "Men better leaders"
label values women_lead men_lab2
tab women_lead

gen women_lead_cat = 4

**-----------------------------
* Independent variables
* gender
generate female = sex_lb 
recode female (-4 = .) (-3 = .) (-2 = .) (-1 = -1) (1 = 0) (2 = 1) 
label variable female "gender: female" 
label define female 0 "man" -1 "Missing" 1 "woman" 
label value female female 
tab female sex_lb

* social class
generate class = class_lb 
recode class (-2 = .) (-1 = .) (1 = 5) (2 = 4) (3 = 3) (4 = 2) (5 = 1) 
label variable class "social class" 
label define class 5 "High/Upper " 1 "low " 4 "Middle class " 2 "working class " 3 "low middle/high working " -1 "Missing " 
label value class class 
tab class class_lb

* marital status
generate married = marstat_lb 
recode married (-4 = .) (-3 = .) (-2 = .) (-1 = -1) (1 = 1) (2 = 0) (3 = 0) 
label variable married "marital status"
label define married 1 "Married or living with partner " -1 "Missing " 0 "Not married " 
label value married married 
tab married marstat_lb

* religion
generate religion = religion_lb 
recode religion (-4 = .) (-3 = .) (-2 = .) (-1 = .) (1 = 1) (2 = 1) (3 = 1) (4 = 1) (5 = 1) ///
	(6 = 1) (7 = 1) (8 = 1) (9 = 3) (10 = 1) (11 = 3) (12 = 3) (13 = 0) (14 = 0) (15 = 1) (16 = 2 ) ///
	(17 = 3) (18 = 1) (19 = 3) (96 = 3) (97 = 0) 
label variable religion "Religious: yes/no + denomination" 
label define religion 0 "not religious " 2 "Muslim " 1 "Christian " 3 "Other " -1 "Missing "
label value religion religion 
tab religion religion_lb

* education - categorical
generate educ = education_lb 
recode educ (-4 = .) (-3 = .) (-2 = .) (-1 = .) (1 = 1) (2 = 1) (3 = 1) (4 = 1) (5 = 1) (6 = 1) ///
	(7 = 1) (8 = 2) (9 = 2) (10 = 2) (11 = 2) (12 = 2) (13 = 2) (14 = 3) (15 = 3) (16 = 2) (17 = 2) 
label variable educ "education: categorical" 
label define educ 2 "secondary " 1 "primary or less " -1 "Missing " 3 "post-secondary " 
label value educ edu 
tab educ education_lb

* employment status
generate employment = employment_lb 
recode employment (-4 = .) (-3 = .) (-2 = .) (-1 = .) (1 = 1) (2 = 1) (3 = 1) (4 = 2 ) (5 = 2 ) ///
	(6 = 2 ) (7 = 2 ) 
label variable employment "employment status" 
label define employment -1 "Missing " 2 "Unemployed " 1 "Working " 
label value employment employment 
tab employment employment_lb

* financial satisfaction
tab econsit_lb, nol
recode econsit_lb (-2=.) (-1=.) (1=5) (2=4) (3=3) (4=2) (5=1)
gen econsit = ((econsit_lb-1)/4)*100
label var econsit "financial satisfaction"
label define sat_lab2 100 "very satisfied" 0 "not at all satisfied"
label values econsit sat_lab2

********* Reduce dataset to only harmonised variables
keep country year data age birth demsat demsat_cat democbest democbest_cat ///
strongleader strongleader_cat trust_gov -trust_church trust_gov_cat -trust_church_cat ///
turnout polint polint_cat women_lead women_lead_cat female class married religion ///
educ employment econsit //income_10 income_5

**** Save prepared data
save "MergedData/temp/Latinobarometer_recoded.dta", replace



/*
**------------------------
* Full democracy
* NOTE: This question was only asked in 2013 and 2004

tab fulldem
recode fulldem (-2=.) (-1=5) // DK were recoded to "I do not understand what a democracy is"
tab fulldem, gen(fulldem) // Create dummy variables for eahc option




**------------------------
* How democracy
* NOTE: This question was only asked 9 times between 1997 and 2013
* Was also asked twice in WVS, but covers same time as LB

tab howdem
recode howdem (-4/-1=.)

gen howdem_dum = (howdem-1)/9
tab howdem_dum
lab var howdem_dum "0-1: Assess how democratic [country] is"
lab def howdem_lbl 0"completly undemcartic" 1"Completley democratic"
lab val howdem_dum howdem_lbl


**------------------------
* Democracic satisfaction
* NOTE: This question was only asked 17 times between 1995 and 2013
* Was also asked in WVS and AB several times, but covers same time as LB

tab demsat
recode demsat (-4/-1=.) (1=4) (2=3) (3=2) (4=1)

gen demsat_dum = (demsat-1)/3
lab var demsat_dum "0-1: Satisfaction with democarcy" 
label define sat_lab1 1 "very satisfied" 0 "not at all satisfied"
label values demsat_dum sat_lab1
tab demsat_dum


**------------------------
* Democracy solves problems
* NOTE: This question was only asked 4 times between 1995 and 2009

tab solvesprob
recode solvesprob (-4/-1=.) (2=0)


**------------------------
* Democracy attitudes combined
pwcorr fulldem1 fulldem5 howdem demsat solvesprob 



**------------------------
* Government approval
* NOTE: This question was only asked 4 times between 2002 and 2013

tab govtapprove
recode govtapprove (-4/-1=.) (2=0)


**------------------------
* Government good to all people
* NOTE: This question was only asked 4 times between 2004 and 2013
* Should be combined with WVS

tab govgood
recode govgood (-4/-1=.) (2=1) (1=0)



**------------------------
* Which best form of gov
* NOTE: This question was only asked 4 times between 1995 and 2013

tab bestgovt
recode bestgovt (-4/-1=.) 
tab bestgovt, gen( bestgovt)


**------------------------
* Democarcy best form of gov
* NOTE: This question was only asked 11 times between 2004 and 2013
* Should be combined with WVS

tab democracybest
recode democracybest (-4/-1=.) (1=4) (2=3) (3=2) (4=1)

gen democracybest_dum = (democracybest-1)/3
label variable democracybest_dum "0-1: Democracy may have problems but it is the best system of govt"
label define agree_lab2 1 "agree" 0 "disagree"
label values democracybest_dum agree_lab2
tab democracybest_dum


pwcorr democracybest bestgovt1 // correlation very weak


**------------------------
* Interpersonal trust

tab trust
recode trust (-4/-1=.) (2=0) 

label define trust_lab1 1 " Most people can be trusted" 0 "one can never be too careful when dealing with others"
label values trust trust_lab1


**------------------------
* Left-right
tab leri
recode leri (-4/-1=.)

gen leri_dum = (leri)/10
tab leri_dum
lab var leri_dum "0-1: Left-Right self-placement"
lab def leri_lbl1 0"Left" 1"Right"
lab val leri_dum leri_lbl1
tab leri_dum




*/
