** --------------------------------------------------------------------------
** RECODING OF DATA: WVS

clear all
cd "/Users/aneundorf/Dropbox/Legacy of authoritarian regimes data/"
*cd "/Users/ldzan/Dropbox/Legacy of authoritarian regimes data/"
*cd "C:/Users/Rosie/Dropbox/Research/legacy of authoritarian regimes/Legacy of authoritarian regimes data/"


** Get data
use "Data for harmonisation/WVS.dta"

**------------------------
* Democracic satisfaction

tab E110
tab E110, nolabel
recode E110 (-4/-1=.) (1=4) (2=3) (3=2) (4=1)

gen demsat = ((E110-1)/3)*100
lab var demsat "0-100: Satisfaction with democarcy" 
label define sat_lab1 100 "very satisfied" 0 "not at all satisfied"
label values demsat sat_lab1
tab demsat

gen demsat_cat = 4
tab demsat_cat
lab var demsat_cat "Nr of categories: Satisfaction with democarcy" 

*bys country: tab year if demsat!=.

tab year if demsat!=.


**------------------------
* Democracy best 

tab E123
tab E123, nolabel
recode E123 (-4/-1=.) (1=4) (2=3) (3=2) (4=1)

gen democbest = ((E123-1)/3)*100
lab var democbest "0-100: Democarcy best form of government" 
label define agree_lab 100 "completly agree" 0 "completly disagree"
label values democbest agree_lab
tab democbest

gen democbest_cat = 4
lab var democbest_cat "Nr of categories: Democarcy best form of government" 

tab year if democbest_cat!=.


**------------------------
* Strong leader 

tab E114
tab E114, nolabel
recode E114 (-4/-1=.) (1=4) (2=3) (3=2) (4=1)

gen strongleader = ((E114-1)/3)*100
lab var strongleader "0-100: Strong leader better than parliament and elections " 
label values strongleader agree_lab
tab strongleader

gen strongleader_cat = 4
lab var strongleader_cat "Nr of categories: Strong leader better"  

tab year if strongleader!=.


**------------------------
* Confidence in institutions

rename E069_01 conf_church
rename E069_02 conf_milit
rename E069_04 conf_media
rename E069_05 conf_union
rename E069_06 conf_police
rename E069_07 conf_parl
rename E069_08 conf_admin
rename E069_11 conf_gov
rename E069_12 conf_party
rename E069_17 conf_judic

foreach i in  gov  parl judic party milit admin police media union church {
tab conf_`i'
tab conf_`i', nolabel
}

label define conf_lab2 100 "A lot" 0 "No trust"

foreach i in  gov  parl judic party milit admin police media union church {
recode conf_`i' (-5/-1=.) (1=4) (2=3) (3=2) (4=1)
gen trust_`i' = ((conf_`i'-1)/3)*100
label variable trust_`i' "0-100: Confidence in `i'"
label values trust_`i' conf_lab2
tab trust_`i'
gen trust_`i'_cat=4
}

**------------------------
* Turnout 

tab1 E257 E264

*tab year E257 
*tab year E264


* Actual turnout
tab E257
tab E257, nolabel

recode E257 (-5/-1=.), gen(turnout)
lab var turnout "0-1: Voted in last nat. election"
lab def trnlbl1 1 "Voted" 0 "Did not vote"
lab val turnout trnlbl1
tab turnout

* Turnout propensity
tab E264
tab E264, nolabel

recode E264 (-5/-1=.) (1/2=1)(3=0), gen(turnout_prob)
lab var turnout_prob "Probability to turnout"
lab def trnlbl 1 "probable turnout" 0 "unprobable turnout"
lab val turnout_prob trnlbl
tab turnout_prob


**------------------------
* Political interest

tab E023
tab E023,nolabel

recode E023 (-5/-1=.) (1=4) (2=3) (3=2) (4=1)

gen polint = ((E023-1)/3)*100
label variable polint "0-100: Political interest"
label define int_lab2 100 "very interested" 0 "not at all interested"
label values polint int_lab2
tab polint

gen polint_cat = 4

**------------------------
* Gender equality

tab D059
tab D059,nolabel

recode D059 (-5/-1=.) 

gen women_lead = ((D059-1)/3)*100
label variable women_lead "0-100: Men NOT better politcal leaders"
label define men_lab2 100 "Men NOT better leaders" 0 "Men better leaders"
label values women_lead men_lab2
tab women_lead

gen women_lead_cat = 4

**-----------------------------
* Independent variables
* gender
generate female = X001 
recode female (-5 = .) (-4 = .) (-3 = .) (-2 = .) (-1 = .) (1 = 0) (2 = 1) 
label variable female "gender: female" 
label define female 0 "man" -1 "Missing" 1 "woman" 
label value female female 
tab female X001

* social class
generate class = X045 
recode class (-5 = .) (-4 = .) (-3 = .) (-2 = .) (-1 = .) (1 = 5) (2 = 4) (3 = 3) (4 = 2) (5 = 1) 
label variable class "social class" 
label define class 5 "High/Upper " 1 "low " 4 "Middle class " 2 "working class " 3 "low middle/high working " -1 "Missing " 
label value class class 
tab class X045

* marital status
generate married = X007 
recode married (-5 = .) (-4 = .) (-3 = .) (-2 = .) (-1 = .) (1 = 1) (2 = 1) (3 = 0) ///
	(4 = 0) (5 = 0) (6 = 0) (7 = 0) (8 = 1) 
label variable married "marital status" 
label define married 1 "Married or living with partner " -1 "Missing " 0 "Not married " 
label value married married
tab married X007 

* religion
generate religion = F025 
recode religion (-5 = .) (-4 = .) (-3 = .) (-2 = .) (-1 = .) (0 = 0) (1 = 1) (2 = 2 ) (3 = 1) ///
	(4 = 3) (5 = 1) (6 = 1) (7 = 1) (8 = 3) (9 = 1) (10 = 1) (11 = 1) (12 = 3) (13 = 1) (14 = 3) ///
	(15 = 1) (16 = 1) (17 = 1) (18 = 1) (19 = 1) (20 = 1) (21 = 3) (22 = 3) (23 = 1) (24 = 2 ) ///
	(25 = 1) (26 = 3) (27 = 3) (28 = 1) (29 = 1) (30 = 1) (31 = 3) (32 = 3) (33 = 1) (34 = 1) ///
	(35 = 1) (36 = 1) (37 = 3) (38 = 3) (39 = 1) (40 = 1) (41 = 1) (42 = 3) (43 = 3) (44 = 1) ///
	(45 = 1) (46 = 1) (47 = 1) (48 = 1) (49 = 2 ) (50 = 3) (51 = 1) (52 = 1) (53 = 3) (54 = 3) ///
	(55 = 1) (56 = 3) (57 = 3) (58 = 3) (59 = 3) (60 = 1) (61 = 1) (62 = 1) (63 = 2 ) (64 = 1) ///
	(65 = 3) (66 = 1) (67 = 3) (68 = 1) (69 = 3) (70 = 2 ) (71 = 3) (72 = 3) (73 = 3) (74 = 3) ///
	(75 = 2 ) (76 = 3) (77 = 3) (78 = 1) (79 = 1) (80 = 3) (81 = 1) (82 = 1) (83 = 1) (84 = 3) ///
	(85 = 3) (86 = 3) (87 = 3) (88 = 3) (89 = 1) (90 = 3) (91 = 3) (12001 = 1) (360001 = 1) ///
	(528001 = 1) (528002 = 1) (710001 = 1) (710002 = 3) 
label variable religion "Religious: yes/no + denomination"
label define religion 0 "not religious " 2 "Muslim " 1 "Christian " 3 "Other " -1 "Missing "
label value religion religion 
tab F025 religion

* Education - categorical
tab X025
generate educ = X025 
recode educ (-5 = .) (-4 = .) (-3 = .) (-2 = .) (-1 = .) (1 = 1) (2 = 1) (3 = 2) (4 = 2) (5 = 2) ///
	(6 = 2) (7 = 3) (8 = 3) 
label variable educ "education: categorical" 
label define educ 2 "secondary " 1 "primary or less " -1 "Missing " 3 "post-secondary " 
label value educ educ
tab educ X025

* Education - years of education

tab X023
tab X023,nolabel
*drop educ_yr
generate educ_yr = X023 
recode educ_yr (-5/-1 = .)  (1/14 = 1) (15/20 = 2) (21/99 = 3) 
label variable educ_yr "education: based on years" 
label value educ_yr educ
tab educ_yr

tab educ_yr educ,  row
tab educ_yr if educ==.

tab educ,m

replace educ = educ_yr if educ==.
drop educ_yr

* employment status
generate employment = X028 
recode employment (-5 = .) (-4 = .) (-3 = .) (-2 = .) (-1 = .) (1 = 1) (2 = 1) (3 = 1) (4 = 2 ) ///
	(5 = 2 ) (6 = 2 ) (7 = 2 ) (8 = 2 ) 
label variable employment "employment status" 
label define employment -1 "Missing " 2 "Unemployed " 1 "Working " 
label value employment employment 
tab employment X028

* financial satisfaction
tab C006, nol
gen econsit = ((C006-1)/9)*100 if C006>=1
label var econsit "financial satisfaction"
label define sat_lab2 100 "very satisfied" 0 "not at all satisfied"
label values econsit sat_lab2

** Ethnicity

rename X051 ethnicity

********* Reduce dataset to only harmonised variables
keep country year data age birth demsat demsat_cat democbest democbest_cat ///
strongleader strongleader_cat trust_gov -trust_church trust_gov_cat -trust_church_cat ///
turnout turnout_prob polint polint_cat women_lead women_lead_cat female class married ///
religion educ employment econsit income_10 income_5 ethnicity


**** Save prepared data
save "MergedData/temp/WVS_recoded.dta", replace





