*** DATA HARMONISATION TEMPLATE - DATA PREPARATION
*** Authors: Anja Neundorf (Nottingham) and Rosalind Shorrocks (Manchester)
*** Part of the ESRC-funded project “Legacies of Authoritarian Regimes on democratic citizenship”
 
**_____________________________________________________________________________
*** GET DATA
** Set your working directory
cd "C:\XXXXXX"

** Load the first wave of the data
use wave1.dta
** Create variable denoting the wave
gen wave1=1
** Keep the variables you want to use
keep var1 var2 var3

** Load the next waves
append using wave2.dta, keep(var4 var5 var6 ...) nolabel gen(wave2)
append using wave3.dta, keep(var7 var8 var9 ...) nolabel gen(wave3)
* Continue for all waves

**_____________________________________________________________________________
*** IDENTIFIER VARIABLES

** Survey year
gen year = 1990 if wave1==1
replace year = 1991 if wave2==1
replace year = 1992 if wave3==1
* Continue for all waves 

** Country
gen country = *WVS country code 1* if var1 = *dataset country code 1*&year==1990| ///
	var4 = *dataset country code 1*&year==1991|var5 = *dataset country code 1*&year==1992
replace country = *WVS country code 2* if var1 = *dataset country code 2*&year==1990| ///
	var4 = *dataset country code 2*&year==1991|var5 = *dataset country code 2*&year==1992
* Continue for all countries
** Label countries
do "Label_Cntry.do"
label values country countrylab

** Dataset
gen data = *code*
lab def datalbl  1 "LB - Latinobarometer" 2 "WVS - World Values Survey" 3 "AB - Americas Barometer" ///
  4 "ISSP - International Social Survey Project" 5 "ANB- Asian Barometer" ///
  6 "AsiaB - Asia Barometer" 7 "AfB - Afrobarometer"  8 "Arab - Arab Barometer" ///
  9 "EVS - European Values Survey" 10 "EB - Eurobarometer (Mannheim trend file only)" ///
  11 "CEEB - Central and Eastern Eurobarometer" 12 "ESS - European Social Survey" ///
  13 "CSES - Comparative Study of Electoral Systems"
lab val data datalbl

*** WITHIN-DATASET HARMONISATION 
*** this can be skipped if a fully harmonised longitudinal file is already provided

** Other variables
** Example 1: the same categories are already available in each wave
gen var_datasetname1 = 1 if var2 = *dataset variable code 1*&year==1990| ///
	var5 = *dataset variable code 1*&year==1991|var8 = *dataset variable code 1*&year==1992
replace var_datasetname1 = 2 if var2 = *dataset variable code 2*&year==1990| ///
	var5 = *dataset variable code 2*&year==1991|var8 = *dataset variable code 2*&year==1992
* Continue for all categories

** Example 2: different categories are available in each wave & collapsing categories is required
gen var_datasetname1 = 1 if var2 = *dataset variable code 1*&year==1990| ///
	var2 = *dataset variable code 2*&year==1990|var5 = *dataset variable code 1*&year==1991| ///
	var8 = *dataset variable code 1*&year==1992
replace var_datasetname1 = 2 if var2 = *dataset variable code 1*&year==1990| ///
	var5 = *dataset variable code 1*&year==1991|var8 = *dataset variable code 1*&year==1992
* Continue for all categories

** Income variables
** Deciles
egen income_10 = xtile(income_var), nq(10) by(country year)
** Quintiles
egen income_5 = xtile(income_var), nq(5) by(country year)

*** CREATE CROSS-DATASET HARMONISED VARIABLES
** Example 1: If dataset response codes are the same as the harmonised variable
rename var_datasetname1 = harmonised_name1
rename var_datasetname2 = harmonised_name2

** Example 2: If dataset response codes are different to the harmonised variable
gen harmonised_name3 = 1 if var_datasetname3==1|var_datasetname3==2
replace harmonised_name3 = 2 if var_datasetname3==3|var_datasetname3==4|var_datasetname3==5

*** Keep the variables you need
keep harmonised_name1 harmonised_name2 harmonised_name3

*** SAVE FILE
save data1_harmonised.dta, replace


*** GO TO TEMPLATE_MERGE.DO





